@@ -18,14 +18,14 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 USA.
 
-Dr. David Kirkby, e-mail drkirkby@ntlworld.com 
+Dr. David Kirkby, e-mail drkirkby at ntlworld.com 
 
 */
-
+#include "config.h"
 #include "definitions.h"
 
 extern double **Vij, **Er;
-extern signed char **cell_type;
+extern unsigned char **oddity;
 extern int dielectrics_to_consider_just_now;
 extern double r;
 extern int width, height;
@@ -35,16 +35,10 @@ double find_energy_per_metre(int w, int h)
   double energy_per_metre=0;
   double Ex, Ey;
 
-  if(cell_type[w][h] >= 0 )
-  {
-    Ex=find_Ex(w,h);
-    Ey=find_Ey(w,h);
-    energy_per_metre+=0.5*EPSILON_0*(Ex*Ex+Ey*Ey);
-    if(cell_type[w][h] >= 0 && dielectrics_to_consider_just_now>1)
-      energy_per_metre*=Er[w][h];
-  }
-  else
-   energy_per_metre=0.0;
-
+  Ex=find_Ex(w,h);
+  Ey=find_Ey(w,h);
+  energy_per_metre+=0.5*EPSILON_0*(Ex*Ex+Ey*Ey);
+  if(dielectrics_to_consider_just_now>1)
+    energy_per_metre*=Er[w][h]; /* second run, energy proportional to Er */
   return(energy_per_metre);
 }
