@@ -18,12 +18,13 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 USA.
 
-Dr. David Kirkby, e-mail drkirkby@ntlworld.com 
+Dr. David Kirkby, e-mail drkirkby at ntlworld.com 
 
 */
 
-#include "definitions.h"
+#include "config.h"
 
+#include "definitions.h"
 
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
@@ -96,9 +97,8 @@ extern double **Vij;
 extern double **Er;
 extern unsigned char *bmp_buff;
 extern int width, height;
-extern size_t size;
 
-void write_fields_for_directional_couplers(char * filename, struct transmission_line_properties data, int odd_or_even)
+void write_fields_for_directional_couplers(char * filename, struct transmission_line_properties data, size_t size, int odd_or_even)
 {
   FILE *Ex_even_bin_fp, *Ey_even_bin_fp, *E_even_bin_fp, *V_even_bin_fp, *U_even_bin_fp;
   FILE *Ex_odd_bin_fp, *Ey_odd_bin_fp, *E_odd_bin_fp, *V_odd_bin_fp, *U_odd_bin_fp;
@@ -200,12 +200,18 @@ void write_fields_for_directional_couplers(char * filename, struct transmission_
 
     permittivity_bmp_fp=get_file_pointer_with_right_filename(filename,".Er.bmp");
 
-    fwrite(bmp_buff,0x36,1,Ex_odd_bmp_fp);
-    fwrite(bmp_buff,0x36,1,Ey_odd_bmp_fp);
-    fwrite(bmp_buff,0x36,1,E_odd_bmp_fp);
-    fwrite(bmp_buff,0x36,1,U_odd_bmp_fp);
-    fwrite(bmp_buff,0x36,1,V_odd_bmp_fp);
-    fwrite(bmp_buff,0x36,1,permittivity_bmp_fp);
+    if( fwrite(bmp_buff,0x36,1,Ex_odd_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#6: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,Ey_odd_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#6: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,E_odd_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#6: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,U_odd_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#6: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,V_odd_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#6: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,permittivity_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#6: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
     offset=-3;
     for(h=height-1;h>=0;h--)
     {
@@ -219,12 +225,12 @@ void write_fields_for_directional_couplers(char * filename, struct transmission_
         E=find_Ex(w,h);
         U=find_energy_per_metre(w,h);
 
-        calculate_colour_data(Ex, maximum_values.Ex_or_Ey_max, w, h, offset,image_data_Ex, COLOUR,&r,&g,&b);
-        calculate_colour_data(Ey, maximum_values.Ex_or_Ey_max, w, h, offset,image_data_Ey, COLOUR,&r,&g,&b);
-        calculate_colour_data(E, maximum_values.E_max, w, h, offset,image_data_E, MONOCHROME,&r,&g,&b);
-        calculate_colour_data(U, maximum_values.U_max, w, h, offset,image_data_U, MONOCHROME,&r,&g,&b);
-        calculate_colour_data(Vij[w][h], maximum_values.V_max, w, h, offset,image_data_V, COLOUR,&r,&g,&b);
-        calculate_colour_data(Er[w][h], MAX_ER, w, h, offset,image_data_Er, MIXED,&r,&g,&b);
+        calculate_colour_data(Ex, maximum_values.Ex_or_Ey_max, w, h, offset,image_data_Ex, COLOUR,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(Ey, maximum_values.Ex_or_Ey_max, w, h, offset,image_data_Ey, COLOUR,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(E, maximum_values.E_max, w, h, offset,image_data_E, MONOCHROME,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(U, maximum_values.U_max, w, h, offset,image_data_U, MONOCHROME,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(Vij[w][h], maximum_values.V_max, w, h, offset,image_data_V, COLOUR,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(Er[w][h], MAX_ER, w, h, offset,image_data_Er, MIXED,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
       }
     } 
     if( fwrite((void *) image_data_Ex,size, 1, Ex_odd_bmp_fp) != 1)
@@ -348,12 +354,18 @@ void write_fields_for_directional_couplers(char * filename, struct transmission_
 
     permittivity_bmp_fp=get_file_pointer_with_right_filename(filename,".Er.bmp");
 
-    fwrite(bmp_buff,0x36,1,Ex_even_bmp_fp);
-    fwrite(bmp_buff,0x36,1,Ey_even_bmp_fp);
-    fwrite(bmp_buff,0x36,1,E_even_bmp_fp);
-    fwrite(bmp_buff,0x36,1,U_even_bmp_fp);
-    fwrite(bmp_buff,0x36,1,V_even_bmp_fp);
-    fwrite(bmp_buff,0x36,1,permittivity_bmp_fp);
+    if( fwrite(bmp_buff,0x36,1,Ex_even_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#1: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,Ey_even_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#1: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,E_even_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#1: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,U_even_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#1: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,V_even_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#1: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
+    if( fwrite(bmp_buff,0x36,1,permittivity_bmp_fp) != 1)
+      exit_with_msg_and_exit_code("Error#1: Failed to write binary file in write_fields_for_directional_couplers.c",WRITE_FAILURE);
     offset=-3;
 #ifdef DEBUG
     fpEvenEx=fopen("Ex.even.txt","w");
@@ -371,12 +383,12 @@ void write_fields_for_directional_couplers(char * filename, struct transmission_
         E=find_Ex(w,h);
         U=find_energy_per_metre(w,h);
 
-        calculate_colour_data(Ex, maximum_values.Ex_or_Ey_max, w, h, offset,image_data_Ex, COLOUR,&r,&g,&b);
-        calculate_colour_data(Ey, maximum_values.Ex_or_Ey_max, w, h, offset,image_data_Ey, COLOUR,&r,&g,&b);
-        calculate_colour_data(E, maximum_values.E_max, w, h, offset,image_data_E, MONOCHROME,&r,&g,&b);
-        calculate_colour_data(U, maximum_values.U_max, w, h, offset,image_data_U, MONOCHROME,&r,&g,&b);
-        calculate_colour_data(Vij[w][h], maximum_values.V_max, w, h, offset,image_data_V, COLOUR,&r,&g,&b);
-        calculate_colour_data(Er[w][h], MAX_ER, w, h, offset,image_data_Er, MIXED,&r,&g,&b);
+        calculate_colour_data(Ex, maximum_values.Ex_or_Ey_max, w, h, offset,image_data_Ex, COLOUR,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(Ey, maximum_values.Ex_or_Ey_max, w, h, offset,image_data_Ey, COLOUR,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(E, maximum_values.E_max, w, h, offset,image_data_E, MONOCHROME,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(U, maximum_values.U_max, w, h, offset,image_data_U, MONOCHROME,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(Vij[w][h], maximum_values.V_max, w, h, offset,image_data_V, COLOUR,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
+        calculate_colour_data(Er[w][h], MAX_ER, w, h, offset,image_data_Er, MIXED,&r,&g,&b, IMAGE_FIDDLE_FACTOR);
       }
     } 
     if( fwrite((void *) &(image_data_Ex[0]),size, 1, Ex_even_bmp_fp) != 1)
